@@ -38,7 +38,7 @@ class plot:
     """
     data必须是dataframe,column_name是特征名字
     """
-    def histplot(self,data,column_name,**kwargs):
+    def histplot(data,column_name,**kwargs):
         X = np.array(data[column_name])
         X_min = min(X)
         X_max = max(X)
@@ -65,7 +65,7 @@ class plot:
         x = np.linspace(mean - 6*sigma, mean + 6*sigma, 100)
         return x,np.exp(-1*((x-mean)**2)/(2*(sigma**2)))/(math.sqrt(2*np.pi) * sigma)
     
-    def gmmplot(self,data,feature_name,**kwargs):
+    def gmmplot(data,feature_name,**kwargs):
         N_COMPONENTS = int(kwargs['n_components'])     if 'n_components'    in kwargs else 2
         X = np.array(data[feature_name])
 
@@ -108,7 +108,7 @@ class plot:
             label_str = "mean=%.2f std=%.2f weight=%.2f"%(mean,std,weight)
             #sns.distplot(datask, bins=100,norm_hist=True,kde=True,fit=scipy.stats.norm,kde_kws={ "label": label_str})
             sns.distplot(datask, bins=feature_bins,norm_hist=True,kde=True,kde_kws={ "label": label_str})
-            x,y = self.normal_distribution(mean, std)
+            x,y = plot.normal_distribution(mean, std)
             plt.plot(x, y, color = "black")
         plt.show()
 
